Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(848)

Unified Diff: chrome/browser/extensions/external_pref_loader.h

Issue 10692168: Moved ExternalExtensionLoaders/Providers into extensions namespace (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Even later master Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/external_pref_loader.h
diff --git a/chrome/browser/extensions/external_pref_extension_loader.h b/chrome/browser/extensions/external_pref_loader.h
similarity index 70%
rename from chrome/browser/extensions/external_pref_extension_loader.h
rename to chrome/browser/extensions/external_pref_loader.h
index c9cf770dcb670ed6c9bc0c45f42b6b635a62a3a7..80797fa1daface021b080360c92161e6ad500f50 100644
--- a/chrome/browser/extensions/external_pref_extension_loader.h
+++ b/chrome/browser/extensions/external_pref_loader.h
@@ -2,10 +2,10 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_EXTENSION_LOADER_H_
-#define CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_EXTENSION_LOADER_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_LOADER_H_
+#define CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_LOADER_H_
-#include "chrome/browser/extensions/external_extension_loader.h"
+#include "chrome/browser/extensions/external_loader.h"
#include <string>
@@ -13,11 +13,13 @@
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
-// A specialization of the ExternalExtensionLoader that uses a json file to
+namespace extensions {
+
+// A specialization of the ExternalLoader that uses a json file to
// look up which external extensions are registered.
// Instances of this class are expected to be created and destroyed on the UI
// thread and they are expecting public method calls from the UI thread.
-class ExternalPrefExtensionLoader : public ExternalExtensionLoader {
+class ExternalPrefLoader : public ExternalLoader {
public:
enum Options {
NONE = 0,
@@ -31,7 +33,7 @@ class ExternalPrefExtensionLoader : public ExternalExtensionLoader {
// |base_path_id| is the directory containing the external_extensions.json
// file or the standalone extension manifest files. Relative file paths to
// extension files are resolved relative to this path.
- explicit ExternalPrefExtensionLoader(int base_path_id, Options options);
+ ExternalPrefLoader(int base_path_id, Options options);
virtual const FilePath GetBaseCrxFilePath() OVERRIDE;
@@ -42,9 +44,9 @@ class ExternalPrefExtensionLoader : public ExternalExtensionLoader {
}
private:
- friend class base::RefCountedThreadSafe<ExternalExtensionLoader>;
+ friend class base::RefCountedThreadSafe<ExternalLoader>;
- virtual ~ExternalPrefExtensionLoader() {}
+ virtual ~ExternalPrefLoader() {}
// Actually searches for and loads candidate standalone extension preference
// files in the path corresponding to |base_path_id|.
@@ -74,16 +76,15 @@ class ExternalPrefExtensionLoader : public ExternalExtensionLoader {
// describing which extensions to load.
FilePath base_path_;
- DISALLOW_COPY_AND_ASSIGN(ExternalPrefExtensionLoader);
+ DISALLOW_COPY_AND_ASSIGN(ExternalPrefLoader);
};
// A simplified version of ExternalPrefExtensionLoader that loads the dictionary
// from json data specified in a string.
-class ExternalTestingExtensionLoader : public ExternalExtensionLoader {
+class ExternalTestingLoader : public ExternalLoader {
public:
- ExternalTestingExtensionLoader(
- const std::string& json_data,
- const FilePath& fake_base_path);
+ ExternalTestingLoader(const std::string& json_data,
+ const FilePath& fake_base_path);
virtual const FilePath GetBaseCrxFilePath() OVERRIDE;
@@ -91,14 +92,16 @@ class ExternalTestingExtensionLoader : public ExternalExtensionLoader {
virtual void StartLoading() OVERRIDE;
private:
- friend class base::RefCountedThreadSafe<ExternalExtensionLoader>;
+ friend class base::RefCountedThreadSafe<ExternalLoader>;
- virtual ~ExternalTestingExtensionLoader();
+ virtual ~ExternalTestingLoader();
FilePath fake_base_path_;
scoped_ptr<DictionaryValue> testing_prefs_;
- DISALLOW_COPY_AND_ASSIGN(ExternalTestingExtensionLoader);
+ DISALLOW_COPY_AND_ASSIGN(ExternalTestingLoader);
};
-#endif // CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_EXTENSION_LOADER_H_
+} // namespace extensions
+
+#endif // CHROME_BROWSER_EXTENSIONS_EXTERNAL_PREF_LOADER_H_
« no previous file with comments | « chrome/browser/extensions/external_pref_extension_loader.cc ('k') | chrome/browser/extensions/external_pref_loader.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -74,16 +76,15 @@ class ExternalPrefExtensionLoader : public ExternalExtensionLoader {
};
-// A simplified version of ExternalPrefExtensionLoader that loads the dictionary
+// A simplified version of ExternalPrefLoader that loads the dictionary
// from json data specified in a string.
This is Rietveld 408576698